@@ -1,6 +1,6 @@
 # ----------------------------------------------------------------------
 #    Copyright (C) 2013 Kshitij Gupta <kgupta8592@gmail.com>
-#    Copyright (C) 2015-2016 Christian Boltz <apparmor@cboltz.de>
+#    Copyright (C) 2015-2018 Christian Boltz <apparmor@cboltz.de>
 #
 #    This program is free software; you can redistribute it and/or
 #    modify it under the terms of version 2 of the GNU General Public
@@ -12,7 +12,7 @@
 #    GNU General Public License for more details.
 #
 # ----------------------------------------------------------------------
-import os
+import ctypes
 import re
 import sys
 import time
@@ -35,7 +35,7 @@ class ReadLog:
         'kernel:\s+(' + RE_kernel_time + '\s+)?(audit:\s+)?type=' + RE_type_num + '\s+' + RE_audit_time_id + RE_aa_or_op,  # v2_6 syslog
         'kernel:\s+(' + RE_kernel_time + '\s+)?' + RE_audit_time_id + 'type=' + RE_type_num + '\s+' + RE_aa_or_op,
         'type=(AVC|APPARMOR[_A-Z]*|' + RE_type_num + ')\s+' + RE_audit_time_id + '(type=' + RE_type_num + '\s+)?' + RE_aa_or_op,  # v2_6 audit and dmesg
-        'type=USER_AVC\s+' + RE_audit_time_id + '.*apparmor=',  # dbus
+        'type=(USER_AVC|1107)\s+' + RE_audit_time_id + '.*apparmor=',  # dbus
         'type=UNKNOWN\[' + RE_type_num + '\]\s+' + RE_audit_time_id + RE_aa_or_op,
         'dbus\[[0-9]+\]:\s+apparmor=',  # dbus
     ]
@@ -43,11 +43,11 @@ class ReadLog:
     # used to pre-filter log lines so that we hand over only relevant lines to LibAppArmor parsing
     RE_LOG_ALL = re.compile('(' + '|'.join(RE_log_parts) + ')')
 
-    def __init__(self, pid, filename, existing_profiles, profile_dir):
+    def __init__(self, pid, filename, active_profiles, profile_dir):
         self.filename = filename
         self.profile_dir = profile_dir
         self.pid = pid
-        self.existing_profiles = existing_profiles
+        self.active_profiles = active_profiles
         self.log = []
         self.debug_logger = DebugLogger('ReadLog')
         self.LOG = None
@@ -118,7 +118,7 @@ class ReadLog:
         ev['protocol'] = event.net_protocol
         ev['sock_type'] = event.net_sock_type
 
-        if event.ouid != 18446744073709551615:  # 2^64 - 1
+        if event.ouid != ctypes.c_ulong(-1).value:  # ULONG_MAX
             ev['fsuid'] = event.fsuid
             ev['ouid'] = event.ouid
 
@@ -419,6 +419,7 @@ class ReadLog:
        'rename_dest',
        'unlink',
        'rmdir',
+       'symlink',
        'symlink_create',
        'link',
        'sysctl',
@@ -446,15 +447,9 @@ class ReadLog:
     def profile_exists(self, program):
         """Returns True if profile exists, False otherwise"""
         # Check cache of profiles
-        if self.existing_profiles.get(program, False):
-            return True
-        # Check the disk for profile
-        prof_path = self.get_profile_filename(program)
-        #print(prof_path)
-        if os.path.isfile(prof_path):
-            # Add to cache of profile
-            self.existing_profiles[program] = prof_path
+        if self.active_profiles.filename_from_profile_name(program):
             return True
+
         return False
 
     def get_profile_filename(self, profile):
